@@ -295,7 +295,10 @@ public final class CIFSFileAccess extends AbstractCIFSAccess implements FileStor
     }
 
     @Override
-    public IDTuple copy(final IDTuple source, final String destFolder, final File update, final InputStream newFil, final List<Field> modifiedFields) throws OXException {
+    public IDTuple copy(final IDTuple source, String version, final String destFolder, final File update, final InputStream newFil, final List<Field> modifiedFields) throws OXException {
+        if (version != CURRENT_VERSION) {
+            throw CIFSExceptionCodes.VERSIONING_NOT_SUPPORTED.create();
+        }
         try {
             final String fid = checkFolderId(source.getFolder(), rootUrl);
             final String url = (fid + source.getId());
